IF OBJECT_ID('[DashboardFeeds]') IS NOT NULL DROP VIEW [DashboardFeeds]
GO

CREATE VIEW [DashboardFeeds]
AS
	SELECT [Feed_Id],
           [Feed_Name],
           [FeedType_Name],
           [Package_Download_Count] = COALESCE((SELECT SUM([Download_Count])
		                                 FROM [NuGetPackageVersionsV2] NPV WITH (READUNCOMMITTED)
										      INNER JOIN [NuGetPackagesV2] NP WITH (READUNCOMMITTED)
											          ON NP.[NuGetPackageV2_Id] = NPV.[NuGetPackageV2_Id]
										WHERE [Feed_Id] = F.[Feed_Id]), 0),
           [Package_Count] = (SELECT COUNT(*)
                                FROM [NuGetPackagesV2] WITH (READUNCOMMITTED)
							   WHERE [Feed_Id] = F.[Feed_Id]),
		   [Version_Count] = (SELECT COUNT(*)
                                FROM [NuGetPackageVersionsV2] NPV WITH (READUNCOMMITTED)
									INNER JOIN [NuGetPackagesV2] NP WITH (READUNCOMMITTED)
										ON NP.[NuGetPackageV2_Id] = NPV.[NuGetPackageV2_Id]
							   WHERE NP.[Feed_Id] = F.[Feed_Id]),
		   [Feed_Size] = COALESCE((SELECT SUM([Package_Size])
		                    FROM [NuGetPackageVersionsV2] NPV WITH (READUNCOMMITTED)
							     INNER JOIN [NuGetPackagesV2] NP WITH (READUNCOMMITTED)
								         ON NP.[NuGetPackageV2_Id] = NPV.[NuGetPackageV2_Id]
						   WHERE [Feed_Id] = F.[Feed_Id]), 0),
		   [Cache_Size] = COALESCE((SELECT SUM([Package_Size])
		                    FROM [NuGetPackageVersionsV2] NPV WITH (READUNCOMMITTED)
							     INNER JOIN [NuGetPackagesV2] NP WITH (READUNCOMMITTED)
								         ON NP.[NuGetPackageV2_Id] = NPV.[NuGetPackageV2_Id]
						   WHERE [Feed_Id] = F.[Feed_Id]
						     AND [Cached_Indicator] = 'Y'), 0),
           F.[Active_Indicator],
		   F.[FeedConfiguration_Xml]
      FROM [Feeds] F WITH (READUNCOMMITTED)
	 WHERE F.[FeedType_Name] IN ('NuGet', 'Chocolatey', 'Deployment', 'PowerShell')

	UNION ALL

	SELECT [Feed_Id],
           [Feed_Name],
           [FeedType_Name],
           [Package_Download_Count] = COALESCE((SELECT SUM(NPV.[Download_Count])
		                                 FROM [NpmPackageVersions] NPV WITH (READUNCOMMITTED)
										      INNER JOIN [NpmPackages] NP WITH (READUNCOMMITTED)
										              ON NP.[Package_Id] = NPV.[Package_Id]
										WHERE [Feed_Id] = F.[Feed_Id]), 0),
           [Package_Count] = (SELECT COUNT(*)
		                        FROM [NpmPackages] WITH (READUNCOMMITTED)
							   WHERE [Feed_Id] = F.[Feed_Id]),
		   [Version_Count] = (SELECT COUNT(*)
		                        FROM [NpmPackageVersions] WITH (READUNCOMMITTED)
							   WHERE [Feed_Id] = F.[Feed_Id]),
		   [Feed_Size] = COALESCE((SELECT SUM(COALESCE([Package_Size], 0))
		                    FROM [NpmPackageVersions] NPV WITH (READUNCOMMITTED)
							     INNER JOIN [NpmPackages] NP WITH (READUNCOMMITTED)
								         ON NP.[Package_Id] = NPV.[Package_Id]
						   WHERE [Feed_Id] = F.[Feed_Id]), 0),
		   [Cache_Size] = COALESCE((SELECT SUM(COALESCE([Package_Size], 0))
		                    FROM [NpmPackageVersions] NPV WITH (READUNCOMMITTED)
							     INNER JOIN [NpmPackages] NP WITH (READUNCOMMITTED)
								         ON NP.[Package_Id] = NPV.[Package_Id]
						   WHERE [Feed_Id] = F.[Feed_Id]
						     AND [Cached_Indicator] = 'Y'), 0),
           F.[Active_Indicator],
		   F.[FeedConfiguration_Xml]
      FROM [Feeds] F WITH (READUNCOMMITTED)
	 WHERE F.[FeedType_Name] = 'npm'

	UNION ALL

	SELECT [Feed_Id],
           [Feed_Name],
           [FeedType_Name],
           [Package_Download_Count] = COALESCE((SELECT SUM([Hit_Count])
		                                 FROM [BowerPackages] WITH (READUNCOMMITTED)
										WHERE [Feed_Id] = F.[Feed_Id]), 0),
           [Package_Count] = (SELECT COUNT(*)
		                        FROM [BowerPackages] WITH (READUNCOMMITTED)
							   WHERE [Feed_Id] = F.[Feed_Id]),
		   [Version_Count] = (SELECT COUNT(*)
		                        FROM [BowerPackages] WITH (READUNCOMMITTED)
							   WHERE [Feed_Id] = F.[Feed_Id]),
		   [Feed_Size] = CAST(0 AS BIGINT),
		   [Cache_Size] = CAST(0 AS BIGINT),
           F.[Active_Indicator],
		   F.[FeedConfiguration_Xml]
      FROM [Feeds] F WITH (READUNCOMMITTED)
	 WHERE F.[FeedType_Name] = 'Bower'

	UNION ALL

	SELECT [Feed_Id],
	       [Feed_Name],
		   [FeedType_Name],
		   [Package_Download_Count] = COALESCE((SELECT SUM(MAF.[Download_Count])
		                                 FROM [MavenArtifactFiles] MAF WITH (READUNCOMMITTED)
										      INNER JOIN [MavenArtifacts] MA WITH (READUNCOMMITTED)
											          ON MA.[MavenArtifact_Id] = MAF.[MavenArtifact_Id]
										WHERE MA.[Feed_Id] = F.[Feed_Id]), 0),
		   [Package_Count] = (SELECT COUNT(*)
		                        FROM [MavenArtifacts] WITH (READUNCOMMITTED)
							   WHERE [Feed_Id] = F.[Feed_Id]),
		   [Version_Count] = (SELECT COUNT(*)
		                        FROM [MavenArtifactFiles] MAF WITH (READUNCOMMITTED)
								   INNER JOIN [MavenArtifacts] MA WITH (READUNCOMMITTED)
								         ON MA.[MavenArtifact_Id] = MAF.[MavenArtifact_Id]
							   WHERE [Feed_Id] = F.[Feed_Id]),
		   [Feed_Size] = COALESCE((SELECT SUM([File_Size])
		                    FROM [MavenArtifactFiles] MAF WITH (READUNCOMMITTED)
							     INNER JOIN [MavenArtifacts] MA WITH (READUNCOMMITTED)
								         ON MA.[MavenArtifact_Id] = MAF.[MavenArtifact_Id]
						   WHERE [Feed_Id] = F.[Feed_Id]), 0),
		   [Cache_Size] = COALESCE((SELECT SUM([File_Size])
		                    FROM [MavenArtifactFiles] MAF WITH (READUNCOMMITTED)
							     INNER JOIN [MavenArtifacts] MA WITH (READUNCOMMITTED)
								         ON MA.[MavenArtifact_Id] = MAF.[MavenArtifact_Id]
						   WHERE [Feed_Id] = F.[Feed_Id]
						     AND MAF.[Cached_Indicator] = 'Y'), 0),
           F.[Active_Indicator],
		   F.[FeedConfiguration_Xml]
	 FROM [Feeds] F WITH (READUNCOMMITTED)
	WHERE F.[FeedType_Name] = 'Maven'

	UNION ALL

	SELECT [Feed_Id],
	       [Feed_Name],
		   [FeedType_Name],
		   [Package_Download_Count] = COALESCE((SELECT SUM(PGP.[Download_Count])
		                                 FROM [ProGetPackages] PGP WITH (READUNCOMMITTED)
										WHERE PGP.[Feed_Id] = F.[Feed_Id]), 0),
		   [Package_Count] = (SELECT COUNT(*)
		                        FROM [ProGetPackages] WITH (READUNCOMMITTED)
							   WHERE [Feed_Id] = F.[Feed_Id]),
		   [Version_Count] = (SELECT COUNT(*)
		                        FROM [ProGetPackageVersions] PGPV WITH (READUNCOMMITTED)
									INNER JOIN [ProGetPackages] PGP WITH (READUNCOMMITTED)
										ON PGP.[ProGetPackage_Id] = PGPV.[ProGetPackage_Id]
							   WHERE [Feed_Id] = F.[Feed_Id]),
		   [Feed_Size] = COALESCE((SELECT SUM([Package_Size])
		                    FROM [ProGetPackageVersions] PGPV WITH (READUNCOMMITTED)
							     INNER JOIN [ProGetPackages] PGP WITH (READUNCOMMITTED)
								         ON PGP.[ProGetPackage_Id] = PGPV.[ProGetPackage_Id]
						   WHERE [Feed_Id] = F.[Feed_Id]), 0),
		   [Cache_Size] = COALESCE((SELECT SUM([Package_Size])
		                    FROM [ProGetPackageVersions] PGPV WITH (READUNCOMMITTED)
							     INNER JOIN [ProGetPackages] PGP WITH (READUNCOMMITTED)
								         ON PGP.[ProGetPackage_Id] = PGPV.[ProGetPackage_Id]
						   WHERE [Feed_Id] = F.[Feed_Id]
						     AND PGPV.[Cached_Indicator] = 'Y'), 0),
           F.[Active_Indicator],
		   F.[FeedConfiguration_Xml]
	 FROM [Feeds] F WITH (READUNCOMMITTED)
	WHERE F.[FeedType_Name] IN ('Universal', 'Romp')

	UNION ALL

	SELECT [Feed_Id],
	       [Feed_Name],
		   [FeedType_Name],
		   [Package_Download_Count] = (SELECT SUM([Download_Count])
		                                FROM [DockerImages] DI WITH (READUNCOMMITTED)
										JOIN [DockerRepositories] DR WITH (READUNCOMMITTED)
										  ON DI.[DockerRepository_Id] = DR.[DockerRepository_Id]
							           WHERE DR.[Feed_Id] = F.[Feed_Id]),
		   [Package_Count] = (SELECT COUNT(*)
		                        FROM [DockerRepositories] DR WITH (READUNCOMMITTED)
							   WHERE DR.[Feed_Id] = F.[Feed_Id]),
		   [Version_Count] = (SELECT COUNT(*)
		                        FROM [DockerImages] DI WITH (READUNCOMMITTED)
								JOIN [DockerRepositories] DR WITH (READUNCOMMITTED)
								  ON DI.[DockerRepository_Id] = DR.[DockerRepository_Id]
							   WHERE DR.[Feed_Id] = F.[Feed_Id]),
		   [Feed_Size] = COALESCE((SELECT SUM(DB.[Blob_Size])
							FROM (SELECT DB.[DockerBlob_Id], DB.[Blob_Size]
								FROM [DockerBlobs] DB WITH (READUNCOMMITTED)
									 JOIN [DockerImageLayers] DIL WITH (READUNCOMMITTED)
									   ON DB.[DockerBlob_Id] = DIL.[DockerBlob_Id]
									 JOIN [DockerImages] DI WITH (READUNCOMMITTED)
									   ON DI.[DockerImage_Id] = DIL.[DockerImage_Id]
									 JOIN [DockerRepositories] DR WITH (READUNCOMMITTED)
									   ON DI.[DockerRepository_Id] = DR.[DockerRepository_Id]
							   WHERE DR.[Feed_Id] = F.[Feed_Id]
							   GROUP BY DB.[DockerBlob_Id], DB.[Blob_Size]) DB

						   ), 0),
						   
		   [Cache_Size] = COALESCE((SELECT SUM(DB.[Blob_Size])
							FROM (SELECT DB.[DockerBlob_Id], DB.[Blob_Size]
								FROM [DockerBlobs] DB WITH (READUNCOMMITTED)
									 JOIN [DockerImageLayers] DIL WITH (READUNCOMMITTED)
									   ON DB.[DockerBlob_Id] = DIL.[DockerBlob_Id]
									 JOIN [DockerImages] DI WITH (READUNCOMMITTED)
									   ON DI.[DockerImage_Id] = DIL.[DockerImage_Id]
									  AND DI.[Cached_Indicator] = 'Y'
									 JOIN [DockerRepositories] DR WITH (READUNCOMMITTED)
									   ON DI.[DockerRepository_Id] = DR.[DockerRepository_Id]
							   WHERE DR.[Feed_Id] = F.[Feed_Id]
							   GROUP BY DB.[DockerBlob_Id], DB.[Blob_Size]) DB
						   ), 0),

           F.[Active_Indicator],
		   F.[FeedConfiguration_Xml]
	 FROM [Feeds] F WITH (READUNCOMMITTED)
	WHERE F.[FeedType_Name] = 'Docker'

	UNION ALL

	SELECT [Feed_Id],
	       [Feed_Name],
		   [FeedType_Name],
		   [Package_Download_Count] = COALESCE((SELECT SUM(RGV.[Download_Count])
		                                 FROM [RubyGemVersions] RGV WITH (READUNCOMMITTED)
										      INNER JOIN [RubyGems] RG WITH (READUNCOMMITTED)
											          ON RG.[Gem_Id] = RGV.[Gem_Id]
									    WHERE RG.[Feed_Id] = F.[Feed_Id]), 0),
		   [Package_Count] = (SELECT COUNT(*)
		                        FROM [RubyGems] WITH (READUNCOMMITTED)
							   WHERE [Feed_Id] = F.[Feed_Id]),
		   [Version_Count] = (SELECT COUNT(*)
		                        FROM [RubyGemVersions] RGV
							     INNER JOIN [RubyGems] RG WITH (READUNCOMMITTED)
							             ON RG.[Gem_Id] = RGV.[Gem_Id]
							   WHERE RG.[Feed_Id] = F.[Feed_Id]),
		   [Feed_Size] = COALESCE((SELECT SUM(RGV.[Gem_Size])
		                    FROM [RubyGemVersions] RGV WITH (READUNCOMMITTED)
							     INNER JOIN [RubyGems] RG WITH (READUNCOMMITTED)
							             ON RG.[Gem_Id] = RGV.[Gem_Id]
						   WHERE RG.[Feed_Id] = F.[Feed_Id]), 0),
		   [Cache_Size] = COALESCE((SELECT SUM(RGV.[Gem_Size])
		                    FROM [RubyGemVersions] RGV WITH (READUNCOMMITTED)
							     INNER JOIN [RubyGems] RG WITH (READUNCOMMITTED)
							             ON RG.[Gem_Id] = RGV.[Gem_Id]
						   WHERE RG.[Feed_Id] = F.[Feed_Id]
						     AND RGV.[Cached_Indicator] = 'Y'), 0),
		   F.[Active_Indicator],
		   F.[FeedConfiguration_Xml]
	  FROM [Feeds] F WITH (READUNCOMMITTED)
	 WHERE F.[FeedType_Name] = 'RubyGems'

	UNION ALL

	SELECT [Feed_Id],
	       [Feed_Name],
		   [FeedType_Name],
		   [Package_Download_Count] = COALESCE((SELECT SUM(VP.[Download_Count])
		                                 FROM [VsixPackages] VP WITH (READUNCOMMITTED)
									    WHERE VP.[Feed_Id] = F.[Feed_Id]), 0),
		   [Package_Count] = (SELECT COUNT(*)
		                        FROM [VsixPackages_Latest] VP WITH (READUNCOMMITTED)
							   WHERE VP.[Feed_Id] = F.[Feed_Id]),
		   [Version_Count] = (SELECT COUNT(*)
		                        FROM [VsixPackages] VP WITH (READUNCOMMITTED)
							   WHERE VP.[Feed_Id] = F.[Feed_Id]),
		   [Feed_Size] = COALESCE((SELECT SUM(VP.[Package_Size])
		                    FROM [VsixPackages] VP WITH (READUNCOMMITTED)
						   WHERE VP.[Feed_Id] = F.[Feed_Id]), 0),
		   [Cache_Size] = COALESCE((SELECT SUM(VP.[Package_Size])
		                    FROM [VsixPackages] VP WITH (READUNCOMMITTED)
						   WHERE VP.[Feed_Id] = F.[Feed_Id]
						     AND VP.[Cached_Indicator] = 'Y'), 0),
		   F.[Active_Indicator],
		   F.[FeedConfiguration_Xml]
	  FROM [Feeds] F WITH (READUNCOMMITTED)
	 WHERE F.[FeedType_Name] = 'VSIX'

	UNION ALL

	SELECT [Feed_Id],
	       [Feed_Name],
		   [FeedType_Name],
		   [Package_Download_Count] = COALESCE((SELECT SUM(DP.[Download_Count])
		                                 FROM [DebianPackages] DP WITH (READUNCOMMITTED)
									    WHERE DP.[Feed_Id] = F.[Feed_Id]), 0),
		   [Package_Count] = (SELECT COUNT(DISTINCT [Package_Name])
		                        FROM [DebianPackages] DP WITH (READUNCOMMITTED)
							   WHERE DP.[Feed_Id] = F.[Feed_Id]),
		   [Version_Count] = (SELECT COUNT(*)
		                        FROM [DebianPackages] DP WITH (READUNCOMMITTED)
							   WHERE DP.[Feed_Id] = F.[Feed_Id]),
		   [Feed_Size] = COALESCE((SELECT SUM(DP.[Package_Size])
		                    FROM [DebianPackages] DP WITH (READUNCOMMITTED)
						   WHERE DP.[Feed_Id] = F.[Feed_Id]), 0),
		   [Cache_Size] = COALESCE((SELECT SUM(DP.[Package_Size])
		                    FROM [DebianPackages] DP WITH (READUNCOMMITTED)
						   WHERE DP.[Feed_Id] = F.[Feed_Id]
						     AND DP.[Cached_Indicator] = 'Y'), 0),
		   F.[Active_Indicator],
		   F.[FeedConfiguration_Xml]
	  FROM [Feeds] F WITH (READUNCOMMITTED)
	 WHERE F.[FeedType_Name] = 'Debian'

	UNION ALL

	SELECT [Feed_Id],
	       [Feed_Name],
		   [FeedType_Name],
		   [Package_Download_Count] = COALESCE((SELECT CAST(SUM(PP.[Download_Count]) AS INT)
		                                 FROM [PypiPackages] PP WITH (READUNCOMMITTED)
									    WHERE PP.[Feed_Id] = F.[Feed_Id]), 0),
		   [Package_Count] = (SELECT COUNT(DISTINCT [Package_Name])
		                        FROM [PypiPackages] PP WITH (READUNCOMMITTED)
							   WHERE PP.[Feed_Id] = F.[Feed_Id]),
		   [Version_Count] = (SELECT COUNT(*)
		                        FROM [PypiPackages] PP WITH (READUNCOMMITTED)
							   WHERE PP.[Feed_Id] = F.[Feed_Id]),
		   [Feed_Size] = COALESCE((SELECT SUM(PP.[Package_Size])
		                    FROM [PypiPackages] PP WITH (READUNCOMMITTED)
						   WHERE PP.[Feed_Id] = F.[Feed_Id]
						     AND PP.[Cached_Indicator] = 'N'), 0),
		   [Cache_Size] = COALESCE((SELECT SUM(PP.[Package_Size])
		                    FROM [PypiPackages] PP WITH (READUNCOMMITTED)
						   WHERE PP.[Feed_Id] = F.[Feed_Id]
						     AND PP.[Cached_Indicator] = 'Y'), 0),
		   F.[Active_Indicator],
		   F.[FeedConfiguration_Xml]
	  FROM [Feeds] F WITH (READUNCOMMITTED)
	 WHERE F.[FeedType_Name] = 'PyPI'

	UNION ALL

	SELECT [Feed_Id],
	       [Feed_Name],
	       [FeedType_Name],
	       [Package_Download_Count] = COALESCE((SELECT CAST(SUM(HC.[Download_Count]) AS INT)
	               FROM [HelmCharts] HC WITH (READUNCOMMITTED)
	              WHERE HC.[Feed_Id] = F.[Feed_Id]), 0),
	       [Package_Count] = (SELECT COUNT(DISTINCT HC.[Chart_Name])
	                            FROM [HelmCharts] HC WITH (READUNCOMMITTED)
	                           WHERE HC.[Feed_Id] = F.[Feed_Id]),
		   [Version_Count] = (SELECT COUNT(*)
	                            FROM [HelmCharts] HC WITH (READUNCOMMITTED)
	                           WHERE HC.[Feed_Id] = F.[Feed_Id]),
	       [Feed_Size] = COALESCE((SELECT SUM(HC.[Chart_Size])
	                                 FROM [HelmCharts] HC WITH (READUNCOMMITTED)
	                                WHERE HC.[Feed_Id] = F.[Feed_Id]
	                                  AND HC.[Cached_Indicator] = 'N'), 0),
	       [Cache_Size] = COALESCE((SELECT SUM(HC.[Chart_Size])
	                        FROM [HelmCharts] HC WITH (READUNCOMMITTED)
	                       WHERE HC.[Feed_Id] = F.[Feed_Id]
	                         AND HC.[Cached_Indicator] = 'Y'), 0),
	       F.[Active_Indicator],
		   F.[FeedConfiguration_Xml]
	  FROM [Feeds] F
	 WHERE F.[FeedType_Name] = 'Helm'

	UNION ALL

	SELECT [Feed_Id],
	       [Feed_Name],
	       [FeedType_Name],
	       [Package_Download_Count] = COALESCE((SELECT CAST(SUM(RPV.[Download_Count]) AS INT)
	                                              FROM [RpmPackages] RP WITH (READUNCOMMITTED)
				                                       INNER JOIN [RpmPackageVersions] RPV WITH (READUNCOMMITTED)
						                                       ON RPV.[RpmPackage_Id] = RP.[RpmPackage_Id]
	                                             WHERE RP.[Feed_Id] = F.[Feed_Id]), 0),
	       [Package_Count] = (SELECT COUNT(DISTINCT RP.[Package_Name])
	                            FROM [RpmPackages] RP WITH (READUNCOMMITTED)
	                           WHERE RP.[Feed_Id] = F.[Feed_Id]),
		   [Version_Count] = (SELECT COUNT(*)
	                            FROM [RpmPackages] RP WITH (READUNCOMMITTED)
								     INNER JOIN [RpmPackageVersions] RPV WITH (READUNCOMMITTED)
									         ON RPV.[RpmPackage_Id] = RP.[RpmPackage_Id]
	                           WHERE RP.[Feed_Id] = F.[Feed_Id]),
	       [Feed_Size] = COALESCE((SELECT SUM(RPV.[Package_Size])
	                                 FROM [RpmPackages] RP WITH (READUNCOMMITTED)
									      INNER JOIN [RpmPackageVersions] RPV WITH (READUNCOMMITTED)
									              ON RPV.[RpmPackage_Id] = RP.[RpmPackage_Id]
	                                WHERE RP.[Feed_Id] = F.[Feed_Id]), 0),
	       [Cache_Size] = 0,
	       F.[Active_Indicator],
		   F.[FeedConfiguration_Xml]
	  FROM [Feeds] F WITH (READUNCOMMITTED)
	 WHERE F.[FeedType_Name] = 'RPM'

GO