EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Connectors_UpdateCachedResponse',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates or updates a connector response.'
GO

IF OBJECT_ID('[Connectors_UpdateCachedResponse]') IS NOT NULL DROP PROCEDURE [Connectors_UpdateCachedResponse]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Connectors_UpdateCachedResponse]
(
	@Connector_Id INT,
	@Request_Hash BINARY(32),
	@Request_Url VARBINARY(2000),
	@Content_Type VARCHAR(50),
	@Content_Length INT,
	@Content_Bytes VARBINARY(MAX)
)
AS BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	UPDATE [ConnectorResponses]
	   SET [Request_Url] = @Request_Url,
	       [Content_Type] = @Content_Type,
		   [Content_Length] = @Content_Length,
		   [Content_Bytes] = @Content_Bytes,
		   [Populated_Date] = GETUTCDATE(),
		   [Request_Count] = 0
	 WHERE [Connector_Id] = @Connector_Id
	   AND [Request_Hash] = @Request_Hash


	IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [ConnectorResponses]
		(
			[Connector_Id],
			[Request_Hash],
			[Request_Url],
			[Content_Type],
			[Content_Length],
			[Content_Bytes],
			[LastUsed_Date],
			[Populated_Date],
			[Request_Count]
		)
		VALUES
		(
			@Connector_Id,
			@Request_Hash,
			@Request_Url,
			@Content_Type,
			@Content_Length,
			@Content_Bytes,
			GETUTCDATE(),
			GETUTCDATE(),
			0
		)
	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Connectors_UpdateCachedResponse] TO [ProGetUser_Role]
GO
