EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'NpmPackages_DeletePackage',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Deletes a package in an npm feed.'
GO

IF OBJECT_ID('[NpmPackages_DeletePackage]') IS NOT NULL DROP PROCEDURE [NpmPackages_DeletePackage]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [NpmPackages_DeletePackage]
(
	@Feed_Id INT,
	@Package_Name NVARCHAR(200),
	@Scope_Name VARCHAR(200),
	@Version_Text VARCHAR(200)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

		DECLARE @Package_Id INT
		SET @Package_Id = (SELECT [Package_Id] FROM [NpmPackages] WHERE [Feed_Id] = @Feed_Id AND [Scope_Name] = @Scope_Name AND [Package_Name] = @Package_Name)

		DELETE [NpmPackageTags]
		 WHERE [Package_Id] = @Package_Id
		   AND [Tag_Version] = @Version_Text

		DELETE [NpmPackageVersions]
		 WHERE [Package_Id] = @Package_Id
		   AND [Version_Text] = @Version_Text

		IF NOT EXISTS (SELECT * FROM [NpmPackageVersions] WHERE [Package_Id] = @Package_Id)
		BEGIN

			DELETE [NpmPackages]
			 WHERE [Package_Id] = @Package_Id

		END

		EXEC [Events_RaiseEvent] 'PKGDEL', @Feed_Id, 'Package_Name', @Package_Name, 'Package_Version', @Version_Text

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [NpmPackages_DeletePackage] TO [ProGetUser_Role]
GO